@@ -39,9 +39,6 @@
 
 (function createTestSuite(window) {
 
-  /**
-   * @unrestricted
-   */
   const TestSuite = class {
     /**
      * Test suite for interactive UI tests.
@@ -96,7 +93,7 @@
    * @param {string} opt_message User message to print if the test fails.
    */
   TestSuite.prototype.assertTrue = function(value, opt_message) {
-    this.assertEquals(true, !!value, opt_message);
+    this.assertEquals(true, Boolean(value), opt_message);
   };
 
   /**
@@ -650,7 +647,8 @@
 
       function checkMetrics(consoleResult) {
         test.assertEquals(
-            '"' + JSON.stringify(metrics) + '"', consoleResult, 'Wrong metrics for params: ' + JSON.stringify(params));
+            JSON.stringify(JSON.stringify(metrics)), consoleResult,
+            'Wrong metrics for params: ' + JSON.stringify(params));
         callback();
       }
     }
@@ -932,7 +930,7 @@
           MobileThrottling.networkPresets[1],
           [
             'online event: online = true',
-            'connection change event: type = cellular; downlinkMax = 0.390625; effectiveType = 2g'
+            'connection change event: type = cellular; downlinkMax = 0.3814697265625; effectiveType = 2g'
           ],
           step3);
     }
@@ -940,7 +938,7 @@
     function step3() {
       testPreset(
           MobileThrottling.networkPresets[0],
-          ['connection change event: type = cellular; downlinkMax = 1.4400000000000002; effectiveType = 3g'],
+          ['connection change event: type = cellular; downlinkMax = 1.373291015625; effectiveType = 3g'],
           test.releaseControl.bind(test));
     }
   };
@@ -987,7 +985,7 @@
 
       function onGotImageData(data) {
         const image = new Image();
-        test.assertTrue(!!data, 'No image data for frame');
+        test.assertTrue(Boolean(data), 'No image data for frame');
         image.addEventListener('load', onLoad);
         image.src = 'data:image/jpg;base64,' + data;
       }
